diff --git a/src/js/salon.js b/src/js/salon.js
index 127a647bc8a4ec9c53f620c8f96a8b12698754ea..356efbee4e24f1709ff41da44edf0f10e46712c1 100644
--- a/src/js/salon.js
+++ b/src/js/salon.js
@@ -1,6 +1,6 @@
 /**
  * @param {FC.HumanState} entity
- * @param {boolean} cheat
+ * @param {boolean} [cheat=false]
  * @returns {HTMLDivElement}
  */
 App.Medicine.Modification.eyeSelector = function(entity, cheat = false) {
diff --git a/src/npc/startingGirls/startingGirls.js b/src/npc/startingGirls/startingGirls.js
index 7fec854b2252b3b7e6cdaddffe3d8cdd14265d4c..1e23b54ad88f632191bcb62438b73566e790f6c6 100644
--- a/src/npc/startingGirls/startingGirls.js
+++ b/src/npc/startingGirls/startingGirls.js
@@ -2059,8 +2059,15 @@ App.StartingGirls.finalize = function(slave) {
 			if (slave.pregSource === -1) {
 				V.PC.counter.slavesKnockedUp++;
 			}
+			// Make newSlave keep certain changes
+			slave.override_H_Color = 1;
+			slave.override_Arm_H_Color = 1;
+			slave.override_Brow_H_Color = 1;
+			slave.override_Skin = 1;
+
 			newSlave(clone(slave));
 		};
+
 		if (V.cash - cost > minimumSlaveCost()) {
 			const {him} = getPronouns(slave);
 			App.UI.DOM.appendNewElement("div", el,
diff --git a/src/npc/startingGirls/startingGirlsPassage.js b/src/npc/startingGirls/startingGirlsPassage.js
index b6ef844e4bbd59402b0715b4694b5ce8250aa9b4..9bed3894a16d6b2b59f4631aa21e1da4329ec789 100644
--- a/src/npc/startingGirls/startingGirlsPassage.js
+++ b/src/npc/startingGirls/startingGirlsPassage.js
@@ -404,7 +404,7 @@ App.StartingGirls.passage = function() {
 	tabBar.addTab("Stats", "stats", App.StartingGirls.stats(V.activeSlave));
 	tabBar.addTab("Family", "family", App.Intro.editFamily(V.activeSlave));
 	tabBar.addTab("Body Mods", "body-mods", App.UI.bodyModification(V.activeSlave, true));
-	tabBar.addTab("Salon", "salon", App.UI.salon(V.activeSlave, true));
+	tabBar.addTab("Salon", "salon", App.UI.salon(V.activeSlave, true, true));
 	tabBar.addTab("Finalize", "finalize", App.StartingGirls.finalize(V.activeSlave),
 		startingSlaveCost(V.activeSlave) > V.cash ? "show-warning" : undefined);
 	el.append(tabBar.render());
diff --git a/src/facilities/salon/salonPassage.js b/src/facilities/salon/salonPassage.js
index d4b4e07a90d4f1c892a5ef4426a4b0d253495c91..ca637f7341ebd9e8df1f532b50824ebd8f131ba0 100644
--- a/src/facilities/salon/salonPassage.js
+++ b/src/facilities/salon/salonPassage.js
@@ -1,9 +1,10 @@
 /**
  * UI for the Salon. Refreshes without refreshing the passage.
  * @param {App.Entity.SlaveState} slave
  * @param {boolean} cheat if true, will hide scenes and keep the player from being billed for changes.
  */
-App.UI.salon = function(slave, cheat = false) {
+App.UI.salon = function(slave, cheat = false, startingGirls = false) {
 	const container = document.createElement("span");
 	container.id = "salon";
 	const {
@@ -20,7 +21,11 @@ App.UI.salon = function(slave, cheat = false) {
 			App.Events.drawEventArt(el, slave);
 			el.append(intro());
 		}
-		el.append(eyewear());
+		if (!startingGirls) {
+			// Starting girls has its own, more powerful, eye modifier which interferes with this one.
+			// TODO: unify them
+			el.append(eyewear());
+		}
 		if (
 			(["leopard", "tiger", "jaguar"].includes(slave.earT) && slave.earTColor !== "hairless")
 			|| ["leopard", "tiger", "jaguar", "gazelle", "tanuki", "raccoon"].includes(slave.tailShape)
@@ -1,9 +1,10 @@
  * UI for the Salon. Refreshes without refreshing the passage.
  * @param {App.Entity.SlaveState} slave
- * @param {boolean} cheat if true, will hide scenes and keep the player from being billed for changes.
+ * @param {boolean} [cheat=false] if true, will hide scenes and keep the player from being billed for changes.
+ * @param {boolean} [startingGirls=false] change systems for starting girls
  */